SystemOrganization addCategory: #GODSpreadsheetTests!

TestCase subclass: #GODSpreadsheetDataTest
	instanceVariableNames: 'godSSData'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GODSpreadsheetTests'!

!GODSpreadsheetDataTest methodsFor: 'initializing' stamp: 'dhk 9/27/2014 17:14'!
setUp
	"inicializa um GODSpreadsheetData com 3 sheets"

	godSSData := GODSpreadsheetData new.
	godSSData createSheetWithName: 'sheet1';
		createSheetWithName: 'sheet2';
		createSheetWithName: 'sheet3'.! !

!GODSpreadsheetDataTest methodsFor: 'testing' stamp: 'dhk 9/27/2014 18:08'!
testChangeName
	|sheet|
	sheet := godSSData getSheetWithName: 'sheet3'.
	godSSData renameSheet: 'sheet3' toName: 'super sheet'.
	self assert: (sheet getName) = 'super sheet'.
	self assert: (godSSData getSheetWithName: 'super sheet') notNil.! !

!GODSpreadsheetDataTest methodsFor: 'testing' stamp: 'dhk 9/27/2014 17:40'!
testCreateSheet
	|tempGodSSData|

	tempGodSSData := GODSpreadsheetData new.

	tempGodSSData createSheetWithName: 'teste'.

	self assert: (tempGodSSData numberOfSheets) = 1.

	self assert: (tempGodSSData getSheet: 1) notNil.
	self assert: (tempGodSSData getSheetWithName: 'teste') notNil.! !

!GODSpreadsheetDataTest methodsFor: 'testing' stamp: 'foa 9/27/2014 18:38'!
testSheetsOrder
	|sheet1 sheet2|

	sheet1 := godSSData getSheet: 1.
	sheet2 := godSSData getSheetWithName: 'sheet1'.
	self assert: sheet1 == sheet2.

	sheet1 := godSSData getSheet: 2.
	sheet2 := godSSData getSheetWithName: 'sheet2'.

	self assert: sheet1 == sheet2.! !

TestCase subclass: #SSCellTest
	instanceVariableNames: 'ssCell'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GODSpreadsheetTests'!

!SSCellTest methodsFor: 'testing' stamp: 'dhk 9/27/2014 17:50'!
testCellCreation
	|cell|

	cell := SSCell new.
	cell setValue: 'alo alo'.
	self assert: (cell getValue) = 'alo alo'! !

TestCase subclass: #SSRowTest
	instanceVariableNames: 'row'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GODSpreadsheetTests'!

!SSRowTest methodsFor: 'initializing' stamp: 'dhk 9/27/2014 18:10'!
setUp

	row := SSRow new.! !

!SSRowTest methodsFor: 'testing' stamp: 'foa 9/27/2014 18:38'!
testCellOperations
	|cell1 cell2 cell3|
	cell1 := SSCell new.
	cell2 := SSCell new.
	cell3 := SSCell new.
	row addCell: cell1 atColumn: 'A'.
	row addCell: cell2 atColumnIndex: 2.
	row addCell: cell3 atColumn: 'C'.
	
	self assert: (row getCell: 'A') == cell1.
	self assert: (row getCellAtIndex: 2) == cell2.
	self assert: (row getCell: 'C') notNil.

	row deleteCell: 'C'.
	row deleteCellAtIndex: 2.

	self assert: (row getCell: 'C') isNil.
	self assert: (row getCellAtIndex: 2) isNil.! !

TestCase subclass: #SSSheetTest
	instanceVariableNames: 'sheet'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GODSpreadsheetTests'!

!SSSheetTest methodsFor: 'initializing' stamp: 'foa 9/27/2014 18:29'!
setUp

	sheet := SSSheet new: 'sheet1'.! !

!SSSheetTest methodsFor: 'testing' stamp: 'foa 9/27/2014 18:37'!
testName

	self assert: (sheet getName) = 'sheet1'.

	sheet changeName: 'sheet2'.
	self assert: (sheet getName) = 'sheet2'.! !

!SSSheetTest methodsFor: 'testing' stamp: 'foa 9/27/2014 18:59'!
testRowOperations

	| row1 row2 cell1 cell2 |

	row1 := sheet createRow.
	row2 := sheet createRowAtIndex: 3.

	self assert: (sheet getRow: 1) == row1.
	self assert: (sheet getRow: 3) == row2.

	sheet deleteRow: 3. 
	self assert: (sheet getRow: 3) isNil.

	cell1 := SSCell new.
	cell2 := SSCell new.

	row1 addCell: cell1 atColumn: 'A';
		   addCell: cell2 atColumn: 'B'.

	self assert: (sheet getColumnNames) = #('A' 'B').

	self assert: (sheet getCellAtRow: 1 atColumn: 'A') == cell1.
	self assert: (sheet getCellAtRow: 1 atColumnIndex: 2) == cell2.! !
